#[repr(i32)]pub enum WindowAnchor {
TopLeft = 0,
Center = 1,
}Expand description
Determines how the frame image is anchored in the window
Variants
Implementations
Sourceimpl WindowAnchor
impl WindowAnchor
Sourceimpl WindowAnchor
impl WindowAnchor
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.