Module server

Module server 

Structs

SimpleServer
A simple server that handles client connections and manages the application service implementing the SimpleService trait. The server listens for incoming connections and spawns a new thread for each new client.