pub struct SimpleServer<ServiceT: SimpleService> { /* private fields */ }Expand description
A simple server that handles client connections and manages the application service implementing the SimpleService trait.
The server listens for incoming connections and spawns a new thread for each new client.
Example: Self-Signed
ⓘ
let (key, private_key) = crate::cert::self_signed(&["localhost"])?;
let config = ServerConfig::builder()
.with_no_client_auth()
.with_single_cert(vec![key.cert.der().clone()], private_key)?;
let server = SimpleServer::new(config);
server.serve()?Implementations
Sourceimpl<ServiceT: SimpleService> SimpleServer<ServiceT>
impl<ServiceT: SimpleService> SimpleServer<ServiceT>
Sourcepub fn new(service: ServiceT, config: ServerConfig) -> Self
pub fn new(service: ServiceT, config: ServerConfig) -> Self
Creates a new SimpleServer instance with the provided server configuration.
The ServerConfig is used to configure the TLS settings for the server.
Sourcepub fn serve(self) -> Result<()>
pub fn serve(self) -> Result<()>
Starts the server and listens for incoming connections on the default port (1122).
This method blocks until the server is stopped or an error occurs.
Sourcepub fn serve_port(self, port: u16) -> Result<()>
pub fn serve_port(self, port: u16) -> Result<()>
Starts the server and listens for incoming connections on the specified port.
This method blocks until the server is stopped or an error occurs.